package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcProjectCommentMapper;
import com.ruoyi.oa.domain.CmcProjectComment;
import com.ruoyi.oa.service.ICmcProjectCommentService;

/**
 * cmc项目审批Service业务层处理
 * 
 * @author cmc
 * @date 2024-04-02
 */
@Service
public class CmcProjectCommentServiceImpl implements ICmcProjectCommentService 
{
    @Autowired
    private CmcProjectCommentMapper cmcProjectCommentMapper;

    /**
     * 查询cmc项目审批
     * 
     * @param projectId cmc项目审批主键
     * @return cmc项目审批
     */
    @Override
    public CmcProjectComment selectCmcProjectCommentByProjectId(String projectId)
    {
        return cmcProjectCommentMapper.selectCmcProjectCommentByProjectId(projectId);
    }

    /**
     * 查询cmc项目审批列表
     * 
     * @param cmcProjectComment cmc项目审批
     * @return cmc项目审批
     */
    @Override
    public List<CmcProjectComment> selectCmcProjectCommentList(CmcProjectComment cmcProjectComment)
    {
        return cmcProjectCommentMapper.selectCmcProjectCommentList(cmcProjectComment);
    }

    /**
     * 新增cmc项目审批
     * 
     * @param cmcProjectComment cmc项目审批
     * @return 结果
     */
    @Override
    public int insertCmcProjectComment(CmcProjectComment cmcProjectComment)
    {
        return cmcProjectCommentMapper.insertCmcProjectComment(cmcProjectComment);
    }

    /**
     * 修改cmc项目审批
     * 
     * @param cmcProjectComment cmc项目审批
     * @return 结果
     */
    @Override
    public int updateCmcProjectComment(CmcProjectComment cmcProjectComment)
    {
        return cmcProjectCommentMapper.updateCmcProjectComment(cmcProjectComment);
    }

    /**
     * 批量删除cmc项目审批
     * 
     * @param projectIds 需要删除的cmc项目审批主键
     * @return 结果
     */
    @Override
    public int deleteCmcProjectCommentByProjectIds(String[] projectIds)
    {
        return cmcProjectCommentMapper.deleteCmcProjectCommentByProjectIds(projectIds);
    }

    /**
     * 删除cmc项目审批信息
     * 
     * @param projectId cmc项目审批主键
     * @return 结果
     */
    @Override
    public int deleteCmcProjectCommentByProjectId(String projectId)
    {
        return cmcProjectCommentMapper.deleteCmcProjectCommentByProjectId(projectId);
    }
}
